==> zio-aws-apigatewayv2_2.13-6.20.58.3-sources.jar: zio/aws/apigatewayv2/model/UpdateModelRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.{
  StringWithLengthBetween1And256,
  __string,
  StringWithLengthBetween0And1024,
  StringWithLengthBetween0And32K,
  StringWithLengthBetween1And128
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateModelRequest(
    apiId: __string,
    contentType: Optional[StringWithLengthBetween1And256] = Optional.Absent,
    description: Optional[StringWithLengthBetween0And1024] = Optional.Absent,
    modelId: __string,
    name: Optional[StringWithLengthBetween1And128] = Optional.Absent,
    schema: Optional[StringWithLengthBetween0And32K] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.UpdateModelRequest = {
    import UpdateModelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.UpdateModelRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .optionallyWith(
        contentType.map(value =>
          StringWithLengthBetween1And256.unwrap(value): java.lang.String
        )
      )(_.contentType)
      .optionallyWith(
        description.map(value =>
          StringWithLengthBetween0And1024.unwrap(value): java.lang.String
        )
      )(_.description)
      .modelId(modelId: java.lang.String)
      .optionallyWith(
        name.map(value =>
          StringWithLengthBetween1And128.unwrap(value): java.lang.String
        )
      )(_.name)
      .optionallyWith(
        schema.map(value =>
          StringWithLengthBetween0And32K.unwrap(value): java.lang.String
        )
      )(_.schema)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.UpdateModelRequest.ReadOnly =
    zio.aws.apigatewayv2.model.UpdateModelRequest.wrap(buildAwsValue())
}
object UpdateModelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.UpdateModelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.UpdateModelRequest =
      zio.aws.apigatewayv2.model.UpdateModelRequest(
        apiId,
        contentType.map(value => value),
        description.map(value => value),
        modelId,
        name.map(value => value),
        schema.map(value => value)
      )
    def apiId: __string
    def contentType: Optional[StringWithLengthBetween1And256]
    def description: Optional[StringWithLengthBetween0And1024]
    def modelId: __string
    def name: Optional[StringWithLengthBetween1And128]
    def schema: Optional[StringWithLengthBetween0And32K]
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getContentType: ZIO[Any, AwsError, StringWithLengthBetween1And256] =
      AwsError.unwrapOptionField("contentType", contentType)
    def getDescription: ZIO[Any, AwsError, StringWithLengthBetween0And1024] =
      AwsError.unwrapOptionField("description", description)
    def getModelId: ZIO[Any, Nothing, __string] = ZIO.succeed(modelId)
    def getName: ZIO[Any, AwsError, StringWithLengthBetween1And128] =
      AwsError.unwrapOptionField("name", name)
    def getSchema: ZIO[Any, AwsError, StringWithLengthBetween0And32K] =
      AwsError.unwrapOptionField("schema", schema)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.UpdateModelRequest
  ) extends zio.aws.apigatewayv2.model.UpdateModelRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val contentType: Optional[StringWithLengthBetween1And256] =
      zio.aws.core.internal
        .optionalFromNullable(impl.contentType())
        .map(value =>
          zio.aws.apigatewayv2.model.primitives
            .StringWithLengthBetween1And256(value)
        )
    override val description: Optional[StringWithLengthBetween0And1024] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value =>
          zio.aws.apigatewayv2.model.primitives
            .StringWithLengthBetween0And1024(value)
        )
    override val modelId: __string = impl.modelId(): __string
    override val name: Optional[StringWithLengthBetween1And128] =
      zio.aws.core.internal
        .optionalFromNullable(impl.name())
        .map(value =>
          zio.aws.apigatewayv2.model.primitives
            .StringWithLengthBetween1And128(value)
        )
    override val schema: Optional[StringWithLengthBetween0And32K] =
      zio.aws.core.internal
        .optionalFromNullable(impl.schema())
        .map(value =>
          zio.aws.apigatewayv2.model.primitives
            .StringWithLengthBetween0And32K(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.UpdateModelRequest
  ): zio.aws.apigatewayv2.model.UpdateModelRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewayv2_3-5.17.130.3-sources.jar: zio/aws/apigatewayv2/model/UpdateModelRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.{
  StringWithLengthBetween1And256,
  __string,
  StringWithLengthBetween0And1024,
  StringWithLengthBetween0And32K,
  StringWithLengthBetween1And128
}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class UpdateModelRequest(
    apiId: __string,
    contentType: Option[StringWithLengthBetween1And256] = None,
    description: Option[StringWithLengthBetween0And1024] = None,
    modelId: __string,
    name: Option[StringWithLengthBetween1And128] = None,
    schema: Option[StringWithLengthBetween0And32K] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.UpdateModelRequest = {
    import UpdateModelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.UpdateModelRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .optionallyWith(
        contentType.map(value =>
          StringWithLengthBetween1And256.unwrap(value): java.lang.String
        )
      )(_.contentType)
      .optionallyWith(
        description.map(value =>
          StringWithLengthBetween0And1024.unwrap(value): java.lang.String
        )
      )(_.description)
      .modelId(__string.unwrap(modelId): java.lang.String)
      .optionallyWith(
        name.map(value =>
          StringWithLengthBetween1And128.unwrap(value): java.lang.String
        )
      )(_.name)
      .optionallyWith(
        schema.map(value =>
          StringWithLengthBetween0And32K.unwrap(value): java.lang.String
        )
      )(_.schema)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.UpdateModelRequest.ReadOnly =
    zio.aws.apigatewayv2.model.UpdateModelRequest.wrap(buildAwsValue())
}
object UpdateModelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.UpdateModelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.UpdateModelRequest =
      zio.aws.apigatewayv2.model.UpdateModelRequest(
        apiId,
        contentType.map(value => value),
        description.map(value => value),
        modelId,
        name.map(value => value),
        schema.map(value => value)
      )
    def apiId: __string
    def contentType: Option[StringWithLengthBetween1And256]
    def description: Option[StringWithLengthBetween0And1024]
    def modelId: __string
    def name: Option[StringWithLengthBetween1And128]
    def schema: Option[StringWithLengthBetween0And32K]
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getContentType: ZIO[Any, AwsError, StringWithLengthBetween1And256] =
      AwsError.unwrapOptionField("contentType", contentType)
    def getDescription: ZIO[Any, AwsError, StringWithLengthBetween0And1024] =
      AwsError.unwrapOptionField("description", description)
    def getModelId: ZIO[Any, Nothing, __string] = ZIO.succeed(modelId)
    def getName: ZIO[Any, AwsError, StringWithLengthBetween1And128] =
      AwsError.unwrapOptionField("name", name)
    def getSchema: ZIO[Any, AwsError, StringWithLengthBetween0And32K] =
      AwsError.unwrapOptionField("schema", schema)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.UpdateModelRequest
  ) extends zio.aws.apigatewayv2.model.UpdateModelRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val contentType: Option[StringWithLengthBetween1And256] = scala
      .Option(impl.contentType())
      .map(value =>
        zio.aws.apigatewayv2.model.primitives
          .StringWithLengthBetween1And256(value)
      )
    override val description: Option[StringWithLengthBetween0And1024] = scala
      .Option(impl.description())
      .map(value =>
        zio.aws.apigatewayv2.model.primitives
          .StringWithLengthBetween0And1024(value)
      )
    override val modelId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.modelId())
    override val name: Option[StringWithLengthBetween1And128] = scala
      .Option(impl.name())
      .map(value =>
        zio.aws.apigatewayv2.model.primitives
          .StringWithLengthBetween1And128(value)
      )
    override val schema: Option[StringWithLengthBetween0And32K] = scala
      .Option(impl.schema())
      .map(value =>
        zio.aws.apigatewayv2.model.primitives
          .StringWithLengthBetween0And32K(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.UpdateModelRequest
  ): zio.aws.apigatewayv2.model.UpdateModelRequest.ReadOnly = new Wrapper(impl)
}
